<?php
/**
* @version		mod_scorpion_videoheader.php - 11/01/2024
* @copyright	Copyright (C) Scorpion Computers and Software, Inc. All rights reserved.
* @license		GNU General Public License version 2 or later; http://www.gnu.org/copyleft/gpl.html
* @email		info@ScorpionComputers.nl
*/
// no direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;

// First we get the parameters from the module
$document = Factory::getDocument();
$baseURL = Uri::root();
$imagefile1 = $params->get( 'imagefile1' );
$videofileMP4 = $params->get( 'videofileMP4' );
$videofileWEBM = $params->get( 'videofileWEBM' );
$videofileOGG = $params->get( 'videofileOGG' );
$videoBGColor = $params->get( 'videoBGColor' );
$playLoop = $params->get( 'playLoop' );
$autoPlay = $params->get( 'autoPlay' );
$showControls = $params->get( 'showControls' );
$playSound = $params->get( 'playSound' );
$fullHeightOnMobile = $params->get( 'fullHeightOnMobile' );
$heightOnMobile = $params->get( 'heightOnMobile', '90' );
$heightOnDesktop = $params->get( 'heightOnDesktop', '90' );
$fillWidth = $params->get( 'fillWidth' );
$topOrBottom = $params->get( 'topOrBottom', 'top' );

// We create html for every given video-format
$mp4Link = $webmLink = $oggLink = "";
if ($videofileMP4 && $videofileMP4 != -1) {
	$mp4Link = '<source src="'.$baseURL.'images/video/'.$videofileMP4.'" type="video/mp4" data-wf-ignore="true" />';
}
if ($videofileWEBM && $videofileWEBM != -1) {
	$webmLink = '<source src="'.$baseURL.'images/video/'.$videofileWEBM.'" type="video/webm" data-wf-ignore="true" />';
}
if ($videofileOGG && $videofileOGG != -1) {
	$oggLink = '<source src="'.$baseURL.'images/video/'.$videofileOGG.'" type="video/ogg" data-wf-ignore="true" />';
}

// We set the values for the video atributes
$muteOrNot = $loopOrNot = $autoPlayOrNot = $videoControls = "";
if(!$playSound) { $muteOrNot = " muted"; }
if($playLoop) { $loopOrNot = " loop"; }
if($showControls) { $videoControls = " controls"; }
if($autoPlay) { $autoPlayOrNot = " autoplay autobuffer playsinline"; }

// We first add the stylesheet that belong to this module
$urlCSS = $baseURL. 'modules/mod_scorpion_videoheader/mod_scorpion_videoheader.css';
$document->addStyleSheet($urlCSS);

// We change the background color to the selected color
$extraStyle = '.video-container { background-color:'.$videoBGColor.'; }'."\r\n";
$extraStyle .= '.video-container { height:'.$heightOnDesktop.'vh; }'."\r\n";

if ($fullHeightOnMobile) {
	$heightOnMobile = 100;
}

$extraStyle .= '@media only screen and (max-width: 600px) {'."\r\n";
$extraStyle .= '.homepage-hero-module { height:'.$heightOnMobile.'vh !important; }'."\r\n";
$extraStyle .= '.homepage-hero-module .video-container { height:'.$heightOnMobile.'vh !important; }'."\r\n";
$extraStyle .= '.homepage-hero-module .video-container video { height:'.$heightOnMobile.'vh !important; }'."\r\n";
$extraStyle .= '.homepage-hero-module .video-container video.fillWidth { width: auto !important; }'."\r\n";
$extraStyle .= '}'."\r\n";
$document->addStyleDeclaration( $extraStyle );

$fillWidthClass = $fillWidth ? 'fillWidth' : '';
$topOrBottomClass = $topOrBottom === 'bottom' ? 'showBottom' : '';

// Now we set the HTML-code that needs to be implemented for this video module
$htmlCode = '<!-- Scorpion Video Header -->'."\r\n"
			. '<div class="homepage-hero-module">'."\r\n"
			. '<div class="video-container">'."\r\n"
			. '<video'.$videoControls.$autoPlayOrNot.$loopOrNot.$muteOrNot.' class="'.$fillWidthClass.' '.$topOrBottomClass.'" data-wf-ignore="true" data-object-fit="cover">'."\r\n"
			. $mp4Link
			. $webmLink
			. $oggLink
			. 'Your browser does not support the video tag. I suggest you upgrade your browser.'."\r\n"
			. '</video>'."\r\n"
			. '<div class="poster hidden">'."\r\n"
			. '<img src="'.$imagefile1.'" alt="Scorpion Video Header image">'."\r\n"
			. '</div>'."\r\n"
			. '</div>'."\r\n"
			. '</div>'."\r\n";

echo $htmlCode;
// End of the code
?>
